@@ -95,14 +95,14 @@ static knot_db_val_t key_NSEC3_name(struct key *k, const knot_dname_t *name,
 		.data = val.data + val.len,
 	};
 	int ret = dnssec_nsec3_hash(&dname, &nsec_p->libknot, &hash);
-	if (ret != DNSSEC_EOK) return VAL_EMPTY;
+	if (ret != KNOT_EOK) return VAL_EMPTY;
 	if (kr_fails_assert(hash.size == NSEC3_HASH_LEN))
 		return VAL_EMPTY;
 
 	#else
 	dnssec_binary_t hash = { .size = 0, .data = NULL };
 	int ret = dnssec_nsec3_hash(&dname, &nsec_p->libknot, &hash);
-	if (ret != DNSSEC_EOK) return VAL_EMPTY;
+	if (ret != KNOT_EOK) return VAL_EMPTY;
 	if (kr_fails_assert(hash.size == NSEC3_HASH_LEN && hash.data))
 		return VAL_EMPTY;
 	memcpy(knot_db_val_bound(val), hash.data, NSEC3_HASH_LEN);
