@@ -50,8 +50,10 @@ Size (`loads_bits` = log2 length):
 
 #include "./kru.h"
 #include "contrib/ucw/lib.h"
-#include "libdnssec/error.h"
-#include "libdnssec/random.h"
+
+// We only need the original libdnssec here, but...
+#include "lib/dnssec.h"
+
 #if USE_AES
 	/// 4-8 rounds should be an OK choice, most likely.
 	#define AES_ROUNDS 4
@@ -225,7 +227,7 @@ static bool kru_initialize(struct kru *kru, int capacity_log, kru_price_t max_de
 
 	kru->loads_bits = loads_bits;
 
-	if (dnssec_random_buffer((uint8_t *)&kru->hash_key, sizeof(kru->hash_key)) != DNSSEC_EOK) {
+	if (dnssec_random_buffer((uint8_t *)&kru->hash_key, sizeof(kru->hash_key)) != KNOT_EOK) {
 		return false;
 	}
 
