@@ -394,6 +394,12 @@ static void answer_finalize(struct kr_request *request)
 		return;
 	}
 
+	if (knot_wire_get_ancount(answer->wire) == 0 && knot_wire_get_nscount(answer->wire) == 0) {
+		/* Let's disable AD flag if the set of RRs covered by it is empty,
+		 * though it seems unclear to vcunat what RFCs say about that special case. */
+		secure = false;
+	}
+
 	/* AD: "negative answers" need more handling. */
 	if (kr_response_classify(answer) != PKT_NOERROR
 	    /* Additionally check for CNAME chains that "end in NODATA",
