@@ -1,9 +1,7 @@
 from typing import List
 
 from knot_resolver.datamodel.network_schema import AddressRenumberingSchema
-from knot_resolver.datamodel.policy_schema import AnswerSchema
 from knot_resolver.datamodel.templates import template_from_str
-from knot_resolver.datamodel.types import PolicyFlagEnum
 
 
 def test_policy_add():
@@ -118,15 +116,3 @@ def test_policy_reroute():
         tmpl.render(reroute=r)
         == f"policy.REROUTE({{['{r[0].source}']='{r[0].destination}'}},{{['{r[1].source}']='{r[1].destination}'}},)"
     )
-
-
-def test_policy_answer():
-    ans = AnswerSchema({"rtype": "AAAA", "rdata": "192.0.2.7"})
-    tmpl_str = """{% from 'macros/policy_macros.lua.j2' import policy_answer %}
-{{ policy_answer(ans) }}"""
-
-    tmpl = template_from_str(tmpl_str)
-    assert (
-        tmpl.render(ans=ans)
-        == f"policy.ANSWER({{[kres.type.{ans.rtype}]={{rdata=kres.str2ip('{ans.rdata}'),ttl={ans.ttl.seconds()}}}}},{str(ans.nodata).lower()})"
-    )
